==> ja-tcsh-nls-roomi-6.08.00.tgz: share/nls/ja_JP.EUC/tcsh.m <==
$ $Id: set1,v 1.2 1995/03/19 18:07:15 christos Exp $
$ Error messages
$set 1 
1 ʸˡְäƤΤ
3 ʸϤĹΤ
4 $< ιԤĹΤ
5 $0 ѤΤդ뤬ʤΤ
6 [] λȤȤƤʤΤ
7 $ Ÿ ] ˤʤȤʤΤ
8 $  : ҤְäƤΤ (%c)
9 źְäƤΤ
10 Ѥ˺줿ֹʤΤ
11 ʸϤ⤦ʤΤ
12 եְ̾äƤΤ
13 globʤΤ
14 ޤɤĤʤΤ
15 ȤʤΤ
16 Ȥ¿Τ
17 ΤꤢϤФΤ
18 ifʤΤ
19 ְäthenʤΤ
20 ʸ󤬳ˤʤΤ
21 %s ĤʤΤ
22 ְämaskʤΤ
23 limitͤϤʤΤ
24 ȤĹΤ
25 פñְ̤äƤ뤫,ʤΤ
26 ѿƤʤΤ
27 Ǥ줯Ȥäֹ꤬᤮Τ
28 ʤֹ椬ְäƤΤ
29 ʤְ̾äƤΤ "kill -l"ǸΤ
30 ѿ̾ϱѻǻϤʤȤʤΤ
31 ѿ̾ĹΤ
32 ѿ̾ϱѿǺʤȤʤΤ
33 shellǤϤ֤ȤȤʤΤ
34 ʸ?
35 ۡǤ줯ȤꤣʤΤ
36 ۡǤ줯ȤꤣѹǤʤΤ
37 ʤ̤뤳ޤɤʤΤ
38 ְäƤΤ
39 Ƥʤ黻ҤΤ
40 ۣʤΤ
41 %sȸդϤ⤦Τ
43 ߤϤäΤ
44 źϰϤޤäƤΤ
45 ԤΤСդʤΤ
46 ʤ֤ϤʤΤ
47 üϤǤʤΤ
48 whileǤforeachǤʤΤ
49 ⤦פʤΤ
50 ȹѤ˹礦ΤʤΤ
51 ְä %c ʤΤ
52 %c פʤΤ
53 ꤬­ʤΤ
54 ѤפʤΤ
55 %s: %s
56 %s
57 Ĥ: jobs [ -l ]
58 ȤϤ֤פIDʤΤ
59 ȤjobϤʤΤ
60 jobϤʤΤ
61 ֤Ѥ˰פʤΤ
62 Forkο %dĶΤ; äȤפƤΤ
63 subshellǤϤ֤ȤȤʤΤ
64 פ %d ĤʤsyncԤΤ
65 %sǤjobĤäƤΤ
66 %sߤޤäjobĤäƤΤ
67 ¾ΤǤ줯ȤꤣϤʤΤ
68 Ǥ줯Ȥꤣä϶äݤʤΤ
69 Ǥ줯Ȥꤣ̾Τ
70 Ĥ: %s [-%s]%s
71 -hդ餰ΤΤڤɤʤΤ
72 󤷤ǤϤʤΤ
73 0ǳ껻ƤޤäΤ
74 0ǳ껻ƤޤäΤ(;׻ʤΤ)
75 ְäץñ̤ʤΤ: "%s"ΰ̣ϤʤʤΤ?
76 󤷤ǤǤʤΤ
77 %sȤΤʤΤ
78 $homeѿꤵƤʤΤ
79 Ĥ: history [-%s] [# number of events]
80 $, ! ⤷ <  $# ⤷ $? Ȥä˻ȤʤΤ
81 ѿ̾˲ԤäƤΤ
82 *  $# ⤷ $? Ȥä˻ȤʤΤ
83 $?<digit> ⤷ $#<digit> ϻȤʤΤ
84 ѿ̾ʤΤ
85 ѿǤä˲ԤäƤΤ
86 ĥФäդСդʤΤ
87 ѿʸ?
88 ְä ! ʤΤ
89 ִϤʤΤ
90 ִʤΤ
91 ɤʤΤ
92 ɤĹ᤮Τ
93 %c ϴְä ! ҤʤΤ
94 μԤʤΤ
95 ִХåեСեƤޤäΤ
96 ְä ! Υ쥯ʤΤ
97 θ̤ϤʤΤ
98 %s: ٥ȤĤʤΤ
99 ")"¿ޤ
99 ")"¿Τ
100 "("¿Τ
101 ( ξְ꤬äƤΤ
102 줯ȸְ̾äƤΤ
103 ۣʤ줯ȽϤʤΤ
104 () Ф << ϻȤʤΤ
105 ۣʤ줯ϤʤΤ
106 ()ξְ꤬äƤΤ
107 ꤢ̵¤פäΤ
108 ѿ"$watch"äȤƤʤΤ
109 ˤ٤ȤäƤʤΤ
110 Ĥ: sched -<item#>.\nUsage: sched [+]hh:mm <command>
111 뤵줿٤ȤϤʤΤ
112 ¹ԤǤ뤳ޤɤϤʤΤ
113 ʤ٤ȳϻ֤ʤΤ
114 am/pmǤŪʻֻϤǤʤΤ
115 termcapʸΰ­ʤΤ
116 Ĥ: settc %s [yes|no]
117 `%s' ΤʤcapabilityʤΤ
118 `%%%c' ΤʤtermcapѤ᤿ʤΤ
119 `%s' ΤȤ¿᤮Τ (%d)
120 `%s'  %d ȤɬפʤΤ
121 Ĥ: echotc [-v|-s] [<capability> [<args>]]
122 %s: %s. ְäƤʤΤ
123 !# ҤȤΤפʤΤ
124 ԴʤդΤäʤΤ
125 줯Сդ򤪤Τ
126 `-%s'ΤʤפʤΤ\nUsage: %s [ -bcdefilmnqstvVxX -Dname[=value] ] [ argument ... ]
127 `-%s'ΤʤפʤΤ\nUsage: %s [ -bcdefFilmnqstvVxX ] [ argument ... ]
128 `-%s'ΤʤפʤΤ\nUsage: %s [ -bcdefilmnqstvVxX ] [ argument ... ]
129 \n"%s"䴰ʤΤ
130 \n'%c' %s ʤΤ
131 \n'%c' ( %s θ)ϴְäѤʤΤ "%s"
132 \n"%s"Դ %s ʤΤ
133 -m-hդ餰ΤΤڤɤʤΤ
134 Ĥ: unlimit [-fh] [limits]
135 $%S ɤʤΤ
136 jobĤʤΤ
137 `%c%c'ΤʤcolorlsʤΤ
$ $Id: set2,v 1.2 1995/03/19 18:07:15 christos Exp $
$ Signal names
$set 2 
1 ̤뤷ʤʤΤ
2 Ϥ󤰤äפʤʤΤ
3 󤿤פȤʤʤΤ
4 ߤΤʤʤΤ
5 ̿᤬ְäƤ뤷ʤΤ
6 Ȥ֤ݤȤȤäפΤʤʤΤ
7 ܡȥʥʤΤ
8 IOTȤäפΤʤʤΤ
9 Ƥयä夹뤫⤷ʤ餷ʤʤΤ
10 λΤʤʤΤ
11 ߤȤäפΤʤʤΤ
12 黻㳰ΤʤʤΤ
13 ̵꽪λΤʤʤΤ
14 ˻Ȥʤ"Σ"ʤΤ
15 ˻Ȥʤ"Σ"ʤΤ
16 ȤΤʤʤΤ
17 ФΤʤʤΤ
18 פϰϤΤʤǤ
19 ڤϰϤΤʤǤ
20 Ƥळ뤬ְäƤ뤷ʤʤΤ
21 ѤפäʤʤΤ
22 यäΤʤʤΤ
23 λΤʤʤΤ
24 Ҥפξ֤Ѥä餷ʤʤΤ
25 Ҥפ󤸤äΤ
26 ApolloꤨʤΤ
27 ҤפߤޤääΤ
28 ҤפäΤ
29 ŸͻҤ餷ʤʤΤ
30 ꤽǤΤ
31 (Ctrl-Break)ˤ֤ʤΤ
32 Ϥǽˤʤä餷ʤʤΤ
33 (select)Ʊ I/O ʤΤ
34 äȤǵޤǤۤ餷ʤʤΤ
35 ¿Ťwake-upʤΤ
36 ¿ŤkillʤΤ
37 FortranƱI/OλʤΤ
38 ꤫ФʤΤ
39 ʤʤΤ
40 CPUȤ餷ʤʤΤ
41 Ƥߤ뤫⤷ʤ餷ʤʤΤ
42 ޤ󤰤 group-no wakeup դ餰ʤΤ
43 äɤʤΤ - (cord -T Ȥäƾܤ򸫤Τ)
44 CRAY Y-MPΤ줸ѤƤʤΤ
45 ׵Ǥ
46 ʤǤΤ
47 ʤǻߤޤäΤ
48 ǤΤ
49 ȤޤäΤ
50 ³ϤΤ
51 ttyϤǤΤ	
52 ttyϤߤޤäΤ	
53 ttyνϤǤΤ	
54 ttyνϤߤޤäΤ	
55 ɤξ֤Ѥä餷ʤʤΤ
56 ɤ礭Ѥä餷ʤʤΤ
57 òξ֤Ѥä餷ʤʤΤ
58 CPUȤ餷ʤʤΤ
59 դ뤬礭뤫餷ʤʤΤ
60 ۻ֤ʤΤ
61 פդ󤰻֤ʤΤ
62 DILʤʤΤ
63 ƻǤ뤤٤ȤȯΤ
64 פLWPS֤ä줿餷ʤʤΤ
65 ڤ LWP ʤʤΤ
66 ڤ CPR ʤʤΤ
67 ڤ CPR ʤʤΤ
68 ܤΤꤢ뤿षʤʤΤ
69 ܤΤꤢ뤿षʤʤΤ
70 ܤΤꤢ뤿षʤʤΤ
71 ͤܤΤꤢ뤿षʤʤΤ
72 ͤܺǸΤΤꤢ뤿षʤʤΤ
73 ܺǸΤΤꤢ뤿षʤʤΤ
74 ܺǸΤΤꤢ뤿षʤʤΤ
75 ǸΤΤꤢ뤿षʤʤΤ
76 LAN Ʊ I/O ʤΤ
77 PTY ɤ߽񤭤ǽˤʤä餷ʤʤΤ
78 I/O ׵ʤΤ
79 HFT ˤɤͿΤ
80 HFT ˤɤrelinguish?ɬפʤΤ
81 HFT ɤȤ뤬äΤ
82 HFT ring bufferˤǡΤ
83 פܹԤΤʤʤΤ
84 Secure Ƥ󤷤󤭡ʤΤ
85 ƤʤΤ
86 ʤ SS$_DEBUG ʤΤ
87 ͥ٤ѹʤΤ
88 ʪΤǤäɤää餷ʤʤΤ
89 ʸϤ뤫餷ʤʤΤ
90 äĤ餷ʤʤΤ
91 ȤäƤʤʤʤΤ
$ $Id: set5,v 1.2 1995/03/19 18:07:15 christos Exp $
$ ed.chared.c
$set 5
1 ƤɽϻȤʤΤ\n
$ $Id: set6,v 1.2 1995/03/19 18:07:15 christos Exp $
$ ed.inputl.c
$set 6
1 :ʤΤޤ 0%o ʤΤ\r\n
2 ϤʤΤ\n
3 ǤäȤʤΤ\n
4 Τ\n
5 Τ\n
6 פޤɤʤΤ\n
7 ۣʤޤɤʤΤ\n
8 *** Ǥ̿ŪʤΤ ***\r\n\n
$ $Id: set8,v 1.2 1995/03/19 18:07:15 christos Exp $
$ ed.term.c
$set 8
1 ΤʤswitchʤΤ
2 ȤޤäƤΤ
$ $Id: set10,v 1.2 1995/03/19 18:07:15 christos Exp $
$ ma.setp.c
$set 10 
1 setpath: '%s' ϤޤɤʤΤ.\n
2 setpath: '%s' ޤɤΤΤȤ­ʤΤ.\n
3 setpath: Ѥ '%s'ƤְäƤΤ\n
4 setpath: %s  %s ˤʤΤ\n
5 setpath: %d  %s Ǥ,ְä֤ʤΤ\n
$ $Id: set11,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.c
$set 11 
1 ٹ: tty(%s)ˤǤʤΤ.\n
2 ,shellˤϤ֤Ȥ뤬ʤΤ.\n
3 ˤ %d ̤ΤäΤ.\n
4 ˤ %d ̤Τä %s ˤΤ.\n
5 ˤ %s뤬Τ.\n
6 
7 ˤ %s뤬 %sˤΤ.\n
$ $Id: set12,v 1.3 1996/04/26 20:31:52 christos Exp $
$ sh.dir.c
$set 12 
1 %s: "%s"μ¹ԤƤߤΤ\n
$ $Id: set13,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.exec.c
$set 13 
1 hash=%-4d dir=%-2d prog=%s\n
2 %d ΤϤäΰ (%d ӤäȤ)\n
3 ǤФäޤ = 0x%08x\n
4 %d , %d , %d%%\n
5 %S: äƤ뤳ޤɤʤΤ.\n
6 %S: ޤɤĤʤΤ\n
7 where: / äƤȻȤʤΤ\n
8 %S ϤꤢȤäƤΤ:
9 %S ϤäƤΤ\n
$ $Id: set15,v 1.3 1996/10/19 17:52:32 christos Exp $
$ sh.func.c
$set 15 
1 %s: %s: %s ʤΤ. (%s ߤä)\n
2 
3 äƤ
4 \040ϡ
$ $Id: set16,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.lex.c
$set 16 
1 tty pgrp  %d  %d˺ꤹΤ\n
2 \nȤ\"logout\"ȤΤ\n
3 \n%sλ\"exit\"ȤΤ\n
4 seek to eval %x %x\n
5 seek to alias %x %x\n
6 seek to file %x\n
7 %d ϴְä seek פʤΤ\n
8 tell eval %x %x\n
9 tell alias %x %x\n
10 tell file %x\n
11 \nȤ\"logout\"ȤΤ(줫%d󤯤꤫Τ)\n
12 \n%sλ\"exit\"ȤΤ(줫%d󤯤꤫Τ)\n
$ $Id: set17,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.proc.c
$set 17 
1 㳲ʤΤ: Фä餦ɤ֤ԤäƤΤ\n
2 %dǽäΤ\n
3 㳲ʤΤ: פդä夬ټ¹Ԥ줿Τ
4 ¹ʤΤ
5 ʤ 
6 %-dǽäΤ 
7 ޤʤΤ
8 㳲ʤΤ: =%-9o
9 \040(coreǤäΤ)
10 \040(wd: 
12 %S: ȤäǤƤΤ\n
13 %S: Ȥä˻ߤޤäƤΤ\n
$ $Id: set18,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.set.c
$set 18 
1 ٹ: ԼĹ PATH ڤΤƤΤ\n
$ $Id: set21,v 1.2 1995/03/19 18:07:15 christos Exp $
$ tc.disc.c
$set 21 
1 뤭ǤʤΤ.\n
2 뤭ǤʤΤ.\n
$ $Id: set24,v 1.2 1995/03/19 18:07:15 christos Exp $
$ tc.sched.c
$set 24 
1 kludge
$ $Id: set29,v 1.2 1995/03/19 18:07:15 christos Exp $
$ tw.help.c
$set 29 
1 %S $BMQ$N$X$k$W$U$!$$$k$,$J$$$N$@$!!A(B\n
$ $Id: set30,v 1.2 1995/03/19 18:07:15 christos Exp $
$ tw.parse.c
$set 30 
1 ޥɳ %d\n
2 λʤΤ %d 
3 λʤΤ %d %S\n
4 %s: ޤäʤΤ.\n
5 items
6 rows
7 %d %sΤ. ꥹȽϤΤ? [n/y] 
8 ɽ = %d\n
9 \ntcsh 顼: õƤ뤫狼ʤʤääΤ!\n
10 ϤǤ줯ȤꤸʤΤ
11 ߤĤʤΤ
12 ɤ߹ळȤǤʤΤ
13 yY

==> ja-tcsh-nls-roomi-6.08.05.tgz: share/nls/ja_JP.EUC/tcsh.m <==
$ $Id: set1,v 1.2 1995/03/19 18:07:15 christos Exp $
$ Error messages
$set 1 
1 ʸˡְäƤΤ
3 ʸϤĹΤ
4 $< ιԤĹΤ
5 $0 ѤΤդ뤬ʤΤ
6 [] λȤȤƤʤΤ
7 $ Ÿ ] ˤʤȤʤΤ
8 $  : ҤְäƤΤ (%c)
9 źְäƤΤ
10 Ѥ˺줿ֹʤΤ
11 ʸϤ⤦ʤΤ
12 դְ̾äƤΤ
13 globʤΤ
14 ޤɤĤʤΤ
15 ȤʤΤ
16 Ȥ¿Τ
17 ΤꤢϤФΤ
18 ifʤΤ
19 ְäthenʤΤ
20 ʸ󤬳ˤʤΤ
21 %s ĤʤΤ
22 ְämaskʤΤ
23 limitͤϤʤΤ
24 ȤĹΤ
25 פñְ̤äƤ뤫,ʤΤ
26 ѿƤʤΤ
27 Ǥ줯Ȥäֹ꤬᤮Τ
28 ʤֹ椬ְäƤΤ
29 ʤְ̾äƤΤ "kill -l"ǸΤ
30 ѿ̾ϱѻǻϤʤȤʤΤ
31 ѿ̾ĹΤ
32 ѿ̾ϱѿǺʤȤʤΤ
33 shellǤϤ֤ȤȤʤΤ
34 ʸ?
35 ۡǤ줯ȤꤣʤΤ
36 ۡǤ줯ȤꤣѹǤʤΤ
37 ʤ̤뤳ޤɤʤΤ
38 ְäƤΤ
39 Ƥʤ黻ҤΤ
40 ۣʤΤ
41 %sȸդϤ⤦Τ
43 ߤϤäΤ
44 źϰϤޤäƤΤ
45 ԤΤСդʤΤ
46 ʤ֤ϤʤΤ
47 üϤǤʤΤ
48 whileǤforeachǤʤΤ
49 ⤦פʤΤ
50 ȹѤ˹礦ΤʤΤ
51 ְä %c ʤΤ
52 %c פʤΤ
53 ꤬­ʤΤ
54 ѤפʤΤ
55 %s: %s
56 %s
57 Ĥ: jobs [ -l ]
58 ȤϤ֤פIDʤΤ
59 ȤjobϤʤΤ
60 jobϤʤΤ
61 ֤Ѥ˰פʤΤ
62 Forkο %dĶΤ; äȤפƤΤ
63 subshellǤϤ֤ȤȤʤΤ
64 פ %d ĤʤsyncԤΤ
65 %sǤjobĤäƤΤ
66 %sߤޤäjobĤäƤΤ
67 ¾ΤǤ줯ȤꤣϤʤΤ
68 Ǥ줯Ȥꤣä϶äݤʤΤ
69 Ǥ줯Ȥꤣ̾Τ
70 Ĥ: %s [-%s]%s
71 -hդ餰ΤΤڤɤʤΤ
72 󤷤ǤϤʤΤ
73 0ǳ껻ƤޤäΤ
74 0ǳ껻ƤޤäΤ(;׻ʤΤ)
75 ְäפñ̤ʤΤ: "%s"ΰ̣ϤʤʤΤ?
76 󤷤ǤǤʤΤ
77 %sȤΤʤΤ
78 $homeѿꤵƤʤΤ
79 Ĥ: history [-%s] [# number of events]
80 $, ! ⤷ <  $# ⤷ $? Ȥä˻ȤʤΤ
81 ѿ̾˲ԤäƤΤ
82 *  $# ⤷ $? Ȥä˻ȤʤΤ
83 $?<digit> ⤷ $#<digit> ϻȤʤΤ
84 ѿ̾ʤΤ
85 ѿǤä˲ԤäƤΤ
86 ĥФäդСդʤΤ
87 ѿʸ?
88 ְä ! ʤΤ
89 ִϤʤΤ
90 ִʤΤ
91 ɤʤΤ
92 ɤĹ᤮Τ
93 %c ϴְä ! ҤʤΤ
94 μԤʤΤ
95 ִФäդСդƤޤäΤ
96 ְä ! Τ줯ʤΤ
97 θ̤ϤʤΤ
98 %s: ٤ȤĤʤΤ
99 ")"¿Τ
100 "("¿Τ
101 ( ξְ꤬äƤΤ
102 줯ȸְ̾äƤΤ
103 ۣʤ줯ȽϤʤΤ
104 () Ф << ϻȤʤΤ
105 ۣʤ줯ϤʤΤ
106 ()ξְ꤬äƤΤ
107 ꤢ̵¤פäΤ
108 ѿ"$watch"äȤƤʤΤ
109 ˤ٤ȤäƤʤΤ
110 Ĥ: sched -<item#>.\nUsage: sched [+]hh:mm <command>
111 뤵줿٤ȤϤʤΤ
112 ¹ԤǤ뤳ޤɤϤʤΤ
113 ʤ٤ȳϻ֤ʤΤ
114 am/pmǤŪʻֻϤǤʤΤ
115 termcapʸΰ­ʤΤ
116 Ĥ: settc %s [yes|no]
117 `%s' ΤʤcapabilityʤΤ
118 `%%%c' ΤʤtermcapѤ᤿ʤΤ
119 `%s' ΤȤ¿᤮Τ (%d)
120 `%s'  %d ȤɬפʤΤ
121 Ĥ: echotc [-v|-s] [<capability> [<args>]]
122 %s: %s. ְäƤʤΤ
123 !# ҤȤΤפʤΤ
124 ԴʤդΤäʤΤ
125 줯Сդ򤪤Τ
126 `-%s'ΤʤפʤΤ\nUsage: %s [ -bcdefilmnqstvVxX -Dname[=value] ] [ argument ... ]
127 `-%s'ΤʤפʤΤ\nUsage: %s [ -bcdefFilmnqstvVxX ] [ argument ... ]
128 `-%s'ΤʤפʤΤ\nUsage: %s [ -bcdefilmnqstvVxX ] [ argument ... ]
129 \n"%s"䴰ʤΤ
130 \n'%c' %s ʤΤ
131 \n'%c' ( %s θ)ϴְäѤʤΤ "%s"
132 \n"%s"Դ %s ʤΤ
133 -m-hդ餰ΤΤڤɤʤΤ
134 Ĥ: unlimit [-fh] [limits]
135 $%S ɤʤΤ
136 jobĤʤΤ
137 `%c%c'ΤʤcolorlsʤΤ
$ $Id: set2,v 1.2 1995/03/19 18:07:15 christos Exp $
$ Signal names
$set 2 
1 ̤뤷ʤʤΤ
2 Ϥ󤰤äפʤʤΤ
3 󤿤פȤʤʤΤ
4 ߤΤʤʤΤ
5 ̿᤬ְäƤ뤷ʤΤ
6 Ȥ֤ݤȤȤäפΤʤʤΤ
7 ܡȥʥʤΤ
8 IOTȤäפΤʤʤΤ
9 Ƥयä夹뤫⤷ʤ餷ʤʤΤ
10 λΤʤʤΤ
11 ߤȤäפΤʤʤΤ
12 黻㳰ΤʤʤΤ
13 ̵꽪λΤʤʤΤ
14 ˻Ȥʤ"Σ"ʤΤ
15 ˻Ȥʤ"Σ"ʤΤ
16 ȤΤʤʤΤ
17 ФΤʤʤΤ
18 פϰϤΤʤǤ
19 ڤϰϤΤʤǤ
20 Ƥळ뤬ְäƤ뤷ʤʤΤ
21 ѤפäʤʤΤ
22 यäΤʤʤΤ
23 λΤʤʤΤ
24 Ҥפξ֤Ѥä餷ʤʤΤ
25 Ҥפ󤸤äΤ
26 ApolloꤨʤΤ
27 ҤפߤޤääΤ
28 ҤפäΤ
29 ŸͻҤ餷ʤʤΤ
30 ꤽǤΤ
31 (Ctrl-Break)ˤ֤ʤΤ
32 Ϥǽˤʤä餷ʤʤΤ
33 (select)Ʊ I/O ʤΤ
34 äȤǵޤǤۤ餷ʤʤΤ
35 ¿Ťwake-upʤΤ
36 ¿ŤkillʤΤ
37 FortranƱI/OλʤΤ
38 ꤫ФʤΤ
39 ʤʤΤ
40 CPUȤ餷ʤʤΤ
41 Ƥߤ뤫⤷ʤ餷ʤʤΤ
42 ޤ󤰤 group-no wakeup դ餰ʤΤ
43 äɤʤΤ - (cord -T Ȥäƾܤ򸫤Τ)
44 CRAY Y-MPΤ줸ѤƤʤΤ
45 ׵Ǥ
46 ʤǤΤ
47 ʤǻߤޤäΤ
48 ǤΤ
49 ȤޤäΤ
50 ³ϤΤ
51 ttyϤǤΤ	
52 ttyϤߤޤäΤ	
53 ttyνϤǤΤ	
54 ttyνϤߤޤäΤ	
55 ɤξ֤Ѥä餷ʤʤΤ
56 ɤ礭Ѥä餷ʤʤΤ
57 òξ֤Ѥä餷ʤʤΤ
58 CPUȤ餷ʤʤΤ
59 դ뤬礭뤫餷ʤʤΤ
60 ۻ֤ʤΤ
61 פդ󤰻֤ʤΤ
62 DILʤʤΤ
63 ƻǤ뤤٤ȤȯΤ
64 פLWPS֤ä줿餷ʤʤΤ
65 ڤ LWP ʤʤΤ
66 ڤ CPR ʤʤΤ
67 ڤ CPR ʤʤΤ
68 ܤΤꤢ뤿षʤʤΤ
69 ܤΤꤢ뤿षʤʤΤ
70 ܤΤꤢ뤿षʤʤΤ
71 ͤܤΤꤢ뤿षʤʤΤ
72 ͤܺǸΤΤꤢ뤿षʤʤΤ
73 ܺǸΤΤꤢ뤿षʤʤΤ
74 ܺǸΤΤꤢ뤿षʤʤΤ
75 ǸΤΤꤢ뤿षʤʤΤ
76 LAN Ʊ I/O ʤΤ
77 PTY ɤ߽񤭤ǽˤʤä餷ʤʤΤ
78 I/O ׵ʤΤ
79 HFT ˤɤͿΤ
80 HFT ˤɤrelinguish?ɬפʤΤ
81 HFT ɤȤ뤬äΤ
82 HFT ring bufferˤǡΤ
83 פܹԤΤʤʤΤ
84 Secure Ƥ󤷤󤭡ʤΤ
85 ƤʤΤ
86 ʤ SS$_DEBUG ʤΤ
87 ͥ٤ѹʤΤ
88 ʪΤǤäɤää餷ʤʤΤ
89 ʸϤ뤫餷ʤʤΤ
90 äĤ餷ʤʤΤ
91 ȤäƤʤʤʤΤ
$ $Id: set5,v 1.2 1995/03/19 18:07:15 christos Exp $
$ ed.chared.c
$set 5
1 ƤɽϻȤʤΤ\n
$ $Id: set6,v 1.2 1995/03/19 18:07:15 christos Exp $
$ ed.inputl.c
$set 6
1 :ʤΤޤ 0%o ʤΤ\r\n
2 ϤʤΤ\n
3 ǤäȤʤΤ\n
4 Τ\n
5 Τ\n
6 פޤɤʤΤ\n
7 ۣʤޤɤʤΤ\n
8 *** Ǥ̿ŪʤΤ ***\r\n\n
$ $Id: set8,v 1.2 1995/03/19 18:07:15 christos Exp $
$ ed.term.c
$set 8
1 ΤʤswitchʤΤ
2 ȤޤäƤΤ
$ $Id: set10,v 1.2 1995/03/19 18:07:15 christos Exp $
$ ma.setp.c
$set 10 
1 setpath: '%s' ϤޤɤʤΤ.\n
2 setpath: '%s' ޤɤΤΤȤ­ʤΤ.\n
3 setpath: Ѥ '%s'ƤְäƤΤ\n
4 setpath: %s  %s ˤʤΤ\n
5 setpath: %d  %s Ǥ,ְä֤ʤΤ\n
$ $Id: set11,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.c
$set 11 
1 ٹ: tty(%s)ˤǤʤΤ.\n
2 ,shellˤϤ֤Ȥ뤬ʤΤ.\n
3 ˤ %d ̤ΤäΤ.\n
4 ˤ %d ̤Τä %s ˤΤ.\n
5 ˤ %s뤬Τ.\n
6 
7 ˤ %s뤬 %sˤΤ.\n
$ $Id: set12,v 1.3 1996/04/26 20:31:52 christos Exp $
$ sh.dir.c
$set 12 
1 %s: "%s"μ¹ԤƤߤΤ\n
$ $Id: set13,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.exec.c
$set 13 
1 hash=%-4d dir=%-2d prog=%s\n
2 %d ΤϤäΰ (%d ӤäȤ)\n
3 ǤФäޤ = 0x%08x\n
4 %d , %d , %d%%\n
5 %S: äƤ뤳ޤɤʤΤ.\n
6 %S: ޤɤĤʤΤ\n
7 where: / äƤȻȤʤΤ\n
8 %S ϤꤢȤäƤΤ:
9 %S ϤäƤΤ\n
$ $Id: set15,v 1.3 1996/10/19 17:52:32 christos Exp $
$ sh.func.c
$set 15 
1 %s: %s: %s ʤΤ. (%s ߤä)\n
2 
3 äƤ
4 \040ϡ
$ $Id: set16,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.lex.c
$set 16 
1 tty pgrp  %d  %d˺ꤹΤ\n
2 \nȤ\"logout\"ȤΤ\n
3 \n%sλ\"exit\"ȤΤ\n
4 seek to eval %x %x\n
5 seek to alias %x %x\n
6 seek to file %x\n
7 %d ϴְä seek פʤΤ\n
8 tell eval %x %x\n
9 tell alias %x %x\n
10 tell file %x\n
11 \nȤ\"logout\"ȤΤ(줫%d󤯤꤫Τ)\n
12 \n%sλ\"exit\"ȤΤ(줫%d󤯤꤫Τ)\n
$ $Id: set17,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.proc.c
$set 17 
1 㳲ʤΤ: Фä餦ɤ֤ԤäƤΤ\n
2 %dǽäΤ\n
3 㳲ʤΤ: פդä夬ټ¹Ԥ줿Τ
4 ¹ʤΤ
5 ʤ 
6 %-dǽäΤ 
7 ޤʤΤ
8 㳲ʤΤ: =%-9o
9 \040(coreǤäΤ)
10 \040(wd: 
12 %S: ȤäǤƤΤ\n
13 %S: Ȥä˻ߤޤäƤΤ\n
$ $Id: set18,v 1.2 1995/03/19 18:07:15 christos Exp $
$ sh.set.c
$set 18 
1 ٹ: ԼĹ PATH ڤΤƤΤ\n
$ $Id: set21,v 1.2 1995/03/19 18:07:15 christos Exp $
$ tc.disc.c
$set 21 
1 뤭ǤʤΤ.\n
2 뤭ǤʤΤ.\n
$ $Id: set24,v 1.2 1995/03/19 18:07:15 christos Exp $
$ tc.sched.c
$set 24 
1 kludge
$ $Id: set29,v 1.2 1995/03/19 18:07:15 christos Exp $
$ tw.help.c
$set 29 
1 %S ѤΤؤפդ뤬ʤΤ\n
$ $Id: set30,v 1.2 1995/03/19 18:07:15 christos Exp $
$ tw.parse.c
$set 30 
1 ޥɳ %d\n
2 λʤΤ %d 
3 λʤΤ %d %S\n
4 %s: ޤäʤΤ.\n
5 items
6 rows
7 %d %sΤ. ꥹȽϤΤ? [n/y] 
8 ɽ = %d\n
9 \ntcsh 顼: õƤ뤫狼ʤʤääΤ!\n
10 ϤǤ줯ȤꤸʤΤ
11 ߤĤʤΤ
12 ɤ߹ळȤǤʤΤ
13 yY
